# EZwald

[![pytest](https://github.com/EmiliaSzynwald/jax-ewald/actions/workflows/pytest.yml/badge.svg)](https://github.com/EmiliaSzynwald/jax-ewald/actions/workflows/pytest.yml)

EZwald is an open-source Python library delivering efficient tools to study charged multilayer van der Waals devices with defects, evalutating electrostatic energy of systems with geometry optimization capabilites, built on JAX for automatic differentiation.

- **Homepage:**
- **Documentation:**
- **Tutorials:**
- **Examples:**
- **Souce code:**

## Installation and Usage

## Getting Started
If you are new to EZwald, start with our tutorials page, where we provide several ready‑to‑run examples that illustrate common use cases and are intended to be modified to fit your needs.

## License
[MIT License](https://github.com/EmiliaSzynwald/EZwald/blob/main/LICENSE)
